@@ -59,8 +59,8 @@ class AutocompleteInterface(object):
         autocomplete_light_autocomplete url
         """
         try:
-            return urlresolvers.reverse('autocomplete_light_autocomplete', args=(
-                self.__class__.__name__,))
+            return urlresolvers.reverse('autocomplete_light_autocomplete',
+                args=(self.__class__.__name__,))
         except urlresolvers.NoReverseMatch, e:
             # Such error will ruin form rendering. It would be automatically
             # silenced because of e.silent_variable_failure=True, which is
